@@ -112,6 +112,9 @@ def _prepare_server(host: str = "",
                     keypass: str = "",
                     ssl_context: SSLContext = None,
                     resources: Dict[str, str] = {},
+                    connection_idle_time=None,
+                    keep_alive=True,
+                    keep_alive_max_request=None,
                     prefer_coroutine=False) -> None:
     with __lock:
         global _server
@@ -148,6 +151,9 @@ def _prepare_server(host: str = "",
     err_pages = _get_error_pages()
     for code, func in err_pages.items():
         _server.map_error_page(code, func)
+    _server.keep_alive = keep_alive
+    _server.connection_idle_time = connection_idle_time
+    _server.keep_alive_max_request = keep_alive_max_request
 
 
 def start(host: str = "",
@@ -160,6 +166,9 @@ def start(host: str = "",
           keypass: str = "",
           ssl_context: SSLContext = None,
           resources: Dict[str, str] = {},
+          connection_idle_time=None,
+          keep_alive=True,
+          keep_alive_max_request=None,
           prefer_coroutine=False) -> None:
     _prepare_server(
         host=host,
@@ -172,9 +181,11 @@ def start(host: str = "",
         keypass=keypass,
         ssl_context=ssl_context,
         resources=resources,
+        connection_idle_time=connection_idle_time,
+        keep_alive=keep_alive,
+        keep_alive_max_request=keep_alive_max_request,
         prefer_coroutine=prefer_coroutine
     )
-
     # start the server
     _server.start()
 
@@ -189,6 +200,9 @@ async def start_async(host: str = "",
                       keypass: str = "",
                       ssl_context: SSLContext = None,
                       resources: Dict[str, str] = {},
+                      connection_idle_time=None,
+                      keep_alive=True,
+                      keep_alive_max_request=None,
                       prefer_coroutine=True) -> None:
     _prepare_server(
         host=host,
@@ -201,6 +215,9 @@ async def start_async(host: str = "",
         keypass=keypass,
         ssl_context=ssl_context,
         resources=resources,
+        connection_idle_time=connection_idle_time,
+        keep_alive=keep_alive,
+        keep_alive_max_request=keep_alive_max_request,
         prefer_coroutine=prefer_coroutine
     )
 
